%define ALD_Ver		1.2.4

Name:         mpfr

License:      GPL
Summary:      This file is part of the GNU MPFR Library.
Group:        System/Libraries
Version:      2.4.2
Release:      4

Source: %{name}-%{version}.tar.xz
Source1: CROSS.sh

%define DestDir		/math

# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%define BUILD_LOCAL_CROSS 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _CROSS 1
%define BUILD_LOCAL_CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1

#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
%define target %{_arch}-%{_vendor}-%{_os}%{__isa_bits}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif
%define target_  %{target}-

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin

%define __os_install_post %{nil}

%define cross_bindir	%{csysdir}%{_bindir}
%define cross_sbindir	%{csysdir}%{_sbindir}
%define cross_libdir	%{csysdir}%{_libdir}
%define cross_includedir %{csysdir}%{_includedir}
%define cross_datadir	%{csysdir}%{_datadir}
%define cross_infodir	%{csysdir}%{_infodir}
%define cross_mandir	%{csysdir}%{_mandir}
%define cross_defaultdocdir %{csysdir}%{_defaultdocdir}
%define cross_docdir	%{cross_defaultdocdir}/%{name}

%define CrossDestDir	/Cross

%define _srcrpmdir	%{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysbindir	%{_prefix}/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}

%define target %{_build}
%define target_  %{nil}

%endif # !_CROSS

%define docdir %{_defaultdocdir}/%{name}

# ------------------- description ------------------------------------
%description
This file is part of the GNU MPFR Library.
# -------------------
%package info
Summary:      Info for %{name}
Group:        Documentation
%description info
Info for %{name}
#-------------------------------
%package doc
Summary:      doc for %{name}
Group:        Documentation
%description doc
doc for %{name}
#-------------------------------
%package devel
Summary:      Libraries for the C compiler
Group:        Development/Libraries
%description devel
These libraries are needed to compile C code.
#-------------------------------
%package devel-shared
Summary:      Libraries for the C compiler
Group:        Development/Libraries
%description devel-shared
These libraries are needed to compile C code.
#-------------------------------
%package devel-static
Summary:      Libraries for the C compiler
Group:        Development/Libraries
%description devel-static
These libraries are needed to compile C code.

#-------------------------------
%package %{TO_ARCH}
Summary:      %{name} Cross-%{TO_ARCH} Libraries
Group:        Development/Libraries
%description %{TO_ARCH}
%{name} Cross-%{TO_ARCH} Libraries
# --------------------------------------
%package %{TO_ARCH}-staticlib
Summary:      %{name} Cross-%{TO_ARCH} static Libraries
Group:        Development/Libraries
%description %{TO_ARCH}-staticlib
%{name} Cross-%{TO_ARCH} static Libraries

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

GCC_VER_STR=`%{target_}gcc -dumpversion`

%if %{_arch} == "i386"
OPTFLAGS="-Os -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
OPT47=`case $GCC_VER_STR in 4.[789].*) echo "-fno-asynchronous-unwind-tables" ;; esac`
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os"
OPT47=`case $GCC_VER_STR in 4.[789].*) echo "-fno-asynchronous-unwind-tables" ;; esac`
%endif
%if %{_arch} == "arm"
OPTFLAGS="-Os -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%endif

%if %{_os} == "mingw"
CFLAGS="$OPTFLAGS -std=gnu99"
LDFLAGS=" "
%else
CFLAGS="$OPTFLAGS $OPT47 -ffunction-sections -fdata-sections -D_GNU_SOURCE -std=gnu99"
LDFLAGS="-Wl,--gc-sections"
%endif

%configure \
	--build=%{_build} \
%if %{_CROSS}
	--host=%{target} \
%endif
%if %{_os} == "mingw"
	--disable-shared \
%else
	--enable-shared \
%endif
	--enable-static \
	--disable-libtool-lock \
	&>FConfigure_log.txt

make &>FMake_log.txt


# ------------------- Install ----------------------------------------
%Install
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt

rm $RPM_BUILD_ROOT%{_libdir}/*.la
rm $RPM_BUILD_ROOT%{_infodir}/dir

rm $RPM_BUILD_ROOT%{docdir}/BUGS
rm $RPM_BUILD_ROOT%{docdir}/NEWS
rm $RPM_BUILD_ROOT%{docdir}/TODO
rm $RPM_BUILD_ROOT%{docdir}/COPYING
rm $RPM_BUILD_ROOT%{docdir}/COPYING.LIB
ln -s /usr/share/doc/gpl-2.0.txt $RPM_BUILD_ROOT%{docdir}/COPYING
ln -s /usr/share/doc/lgpl-2.1.txt $RPM_BUILD_ROOT%{docdir}/COPYING.LIB

%if %{_CROSS} && %{BUILD_LOCAL_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=%{BUILD_LOCAL_CROSS}
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
rm -r $RPM_BUILD_ROOT%{cross_infodir}
rm -r $RPM_BUILD_ROOT%{cross_docdir}/examples
rm $RPM_BUILD_ROOT%{cross_docdir}/FAQ.html
%endif

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} -r %{DestDir} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 

DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}
DEC=%{version}-%{release}.%{_build_cpu}.rpm
DDC=%{_rpmdir}/%{_build_cpu}/%{ALD_Ver}%{CrossDestDir}/%{TO_ARCH}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
%if (%{_os} == "mingw")
  rm %{name}-$SE
%if %{BUILD_LOCAL_CROSS}
  mkdir -p $DDC
  mv %{name}-%{TO_ARCH}-$SE $DDC/%{name}-%{TO_ARCH}-$DEC
%endif #BUILD_LOCAL_CROSS
%else  #mingw
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-doc-$SE $DD/%{name}-doc-$DE
  mv %{name}-info-$SE $DD/%{name}-info-$DE
  mv %{name}-devel-$SE $DD/%{name}-devel-$DE
  mv %{name}-devel-shared-$SE $DD/%{name}-devel-shared-$DE
  mv %{name}-devel-static-$SE $DD/%{name}-devel-static-$DE
%if %{BUILD_LOCAL_CROSS}
  mkdir -p $DDC
  mv %{name}-%{TO_ARCH}-$SE $DDC/%{name}-%{TO_ARCH}-$DEC
  mv %{name}-%{TO_ARCH}-staticlib-$SE $DDC/%{name}-%{TO_ARCH}-staticlib-$DEC
%endif #BUILD_LOCAL_CROSS
%endif #!mingw
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
%if (%{_os} == "mingw")
  TMP_TO=$DD
%else
  TMP_TO=$DD/tar
%endif
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r usr $tmp/
%if (%{_os} == "mingw")
  zip -9 -r $tmp.zip $tmp >/dev/null
  mv $tmp.zip $TMP_TO
%else
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
%endif
  rm -r $tmp
%if %{BUILD_LOCAL_CROSS}
  TMP_TO=$DDC/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{TO_ARCH}-%{version}-%{release}.%{_build_cpu}
  mkdir -p $tmp
  cp -r cross $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
%endif
popd
%endif  #BUILD_TAR

# ------------------- Files ------------------------------------------
%if %{_os} == "mingw"
%files
%{_prefix}

%if %{BUILD_LOCAL_CROSS}
%files %{TO_ARCH}
%{csysdir}
%endif #!BUILD_LOCAL_CROSS
%else  #mingw

%files
%{_libdir}/*.so.*
%{docdir}/AUTHORS
%{docdir}/COPYING
%{docdir}/COPYING.LIB

%files doc
%{docdir}/examples
%{docdir}/FAQ.html

%files info
%{_infodir}

%files devel
%{_includedir}

%files devel-shared
%{_libdir}/*.so

%files devel-static
%{_libdir}/*.a

%if %{BUILD_LOCAL_CROSS}

%files %{TO_ARCH}
%{cross_includedir}
%{cross_libdir}/*.so.*
%{cross_libdir}/*.so
%{cross_docdir}

%files %{TO_ARCH}-staticlib
%{cross_libdir}/*.a

%endif #!BUILD_LOCAL_CROSS
%endif #!mingw
